OCaml API Documentation
=======================

.. toctree::
   :maxdepth: 1

   OCaml Package <https://bitwuzla.github.io/docs/ocaml/index.html>
   OCaml Interface <https://bitwuzla.github.io/docs/ocaml/bitwuzla-cxx/Bitwuzla_cxx/index.html>
   Quickstart <https://bitwuzla.github.io/docs/ocaml/bitwuzla-cxx/index.html#quickstart>
   Examples <https://bitwuzla.github.io/docs/ocaml/bitwuzla-cxx/index.html#examples>

